<template>
  <div style="width: 100%; height: 100%">
    <div class="left-top" v-if="disForm == '行政区划仿真'">
      行政区划仿真（30m精度）
    </div>
    <div class="left-top" v-if="disForm == '重点区域仿真'">
      重点区域仿真（10m精度）
    </div>
    <div class="forms">
      <el-form :model="forms" label-width="auto" style="max-width: 600px">
        <el-form-item label="行政区域:" v-if="disForm == '行政区划仿真'">
          <el-select
            v-model="forms.eare"
            placeholder="Select"
            style="max-width: 600px"
          >
            <el-option
              v-for="item in cityOptions"
              :key="item.value"
              :label="item.label"
              :value="item.value"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="上传参数">
          <el-upload
            v-model:file-list="forms.fileList"
            class="upload-demo"
            action="https://run.mocky.io/v3/9d059bf9-4660-45f2-925d-ce80ad6c4d15"
            multiple
            :on-preview="handlePreview"
            :on-remove="handleRemove"
            :before-remove="beforeRemove"
            :limit="3"
            :on-exceed="handleExceed"
            :before-upload="beforeUpload"
            accept=".xlsx,.xls,.csv"
          >
            <el-button type="primary">点击上传降雨数据</el-button>
            <template #append>mm/h</template>
          </el-upload>
        </el-form-item>
        <el-form-item label="重点区域" v-if="disForm == '重点区域仿真'">
          <el-select
            v-model="forms.eares"
            placeholder="Select"
            style="max-width: 600px"
          >
            <el-option
              v-for="item in earesOptions"
              :key="item.value"
              :label="item.label"
              :value="item.value"
            />
          </el-select>
        </el-form-item>

        <el-form-item label="降雨量:">
          <el-input
            v-model="forms.rainfall"
            style="max-width: 600px"
            placeholder="Please input"
          >
            <template #append>mm</template>
          </el-input>
        </el-form-item>
        <el-form-item label="降雨时长:">
          <el-input
            v-model="forms.duration"
            style="max-width: 600px"
            placeholder="Please input"
          >
            <template #append>h</template>
          </el-input></el-form-item
        >
        <el-form-item label="降雨强度:">
          <el-input
            v-model="forms.intensity"
            style="max-width: 600px"
            placeholder="Please input"
          >
            <template #append>mm/h</template>
          </el-input>
        </el-form-item>
        <el-form-item label="仿真参数:"> </el-form-item>
      </el-form>
      <div style="display: flex; justify-content: flex-end">
        <el-button>保存方案</el-button>
        <el-button @click="startPlay">开始模拟</el-button>
      </div>
    </div>
  </div>
</template>
<script setup>
import { reactive, ref, watch, inject } from "vue";
import { initeWaterPrimitiveView } from "@/utils/water";

// 注入父组件提供的方法
const { startSimulate, endSimulate } = inject("simulateActions");

// const emit = defineEmits(["start", "end"]);
// function endPlay() {
//   emit("end");
// }

function startPlay() {
  initeWaterPrimitiveView();
  startSimulate();
}

const value = ref("");

const cityOptions = [
  {
    value: "北京市",
    label: "北京市",
  },
  {
    value: "东城区",
    label: "东城区",
  },
  {
    value: "西城区",
    label: "西城区",
  },
  {
    value: "朝阳区",
    label: "朝阳区",
  },
  {
    value: "海淀区",
    label: "海淀区",
  },
  {
    value: "丰台区",
    label: "丰台区",
  },
  {
    value: "石景山区",
    label: "石景山区",
  },
  {
    value: "门头沟区",
    label: "门头沟区",
  },
  {
    value: "房山区",
    label: "房山区",
  },
  {
    value: "通州区",
    label: "通州区",
  },
  {
    value: "顺义区",
    label: "顺义区",
  },
  {
    value: "昌平区",
    label: "昌平区",
  },
  {
    value: "大兴区",
    label: "大兴区",
  },
  {
    value: "怀柔区",
    label: "怀柔区",
  },
  {
    value: "平谷区",
    label: "平谷区",
  },
  {
    value: "密云区",
    label: "密云区",
  },
  {
    value: "延庆区",
    label: "延庆区",
  },
];
const earesOptions = [
  {
    value: "孙胡沟",
    label: "孙胡沟",
  },
  {
    value: "鱼水洞后沟",
    label: "鱼水洞后沟",
  },
  {
    value: "于家西沟",
    label: "于家西沟",
  },
  {
    value: "北河沟",
    label: "北河沟",
  },
  {
    value: "龙泉峪村",
    label: "龙泉峪村",
  },
];

const forms = reactive({
  eare: "北京市",
  eares: "孙胡沟",
  rainfall: "50",
  duration: "5",
  intensity: "70",
  fileList: [],
});

function handleRemove(file, uploadFiles) {
  console.log(file, uploadFiles);
}

function handlePreview(uploadFile) {
  console.log(uploadFile);
}

function handleExceed(files, uploadFiles) {
  ElMessage.warning(
    `The limit is 3, you selected ${files.length} files this time, add up to ${
      files.length + uploadFiles.length
    } totally`
  );
}
const beforeUpload = (file) => {
  const allowedTypes = [
    "application/vnd.ms-excel",
    "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
    "text/csv",
    "application/csv",
    "text/x-csv",
    "application/x-csv",
    "text/comma-separated-values",
    "text/x-comma-separated-values",
  ];

  const isAllowed = allowedTypes.includes(file.type);
  const extension = file.name.split(".").pop().toLowerCase();
  const isExtensionValid = ["xls", "xlsx", "csv"].includes(extension);

  if (!isAllowed || !isExtensionValid) {
    ElMessage.error("只能上传 Excel (.xls, .xlsx) 或 CSV 文件");
    return false; // 阻止上传
  }

  return true; // 允许上传
};

function beforeRemove(uploadFile, uploadFiles) {
  return ElMessageBox.confirm(
    `Cancel the transfer of ${uploadFile.name} ?`
  ).then(
    () => true,
    () => false
  );
}

const disForm = ref("");

// 定义 Props
const props = defineProps({
  clickValue: String,
});

// 监听 Props 变化
watch(
  () => props.clickValue,
  (newValue) => {
    disForm.value = newValue || "行政区划仿真";
  },
  { immediate: true, deep: true }
);
</script>
<style lang="less" scoped>
.forms {
  background: url("@/assets/img/screen/leftbg.png");
  margin-top: 10px;
  width: 100%;
  height: 100%;
  padding: 10px 10px 0px 0px;
  box-sizing: border-box;
}
/deep/ .el-input-group__append,
.el-input-group__prepend {
  background-color: #084b42;
  color: #fff;
}
/deep/ .el-form-item__label {
  color: #61f7d4 !important;
}
</style>
